@@ -23,7 +23,7 @@ SUPPORTED_LANGUAGES = "en,fr,de,nl,es,pt,it,zh,ar,hi,ur,fa,ru"
 
 
 class PySDBSegmenter(SegmenterBase, ABC):
-    """Rule-based segmenter relying on [PySBD](https://github.com/nipunsadvilkar/pySBD).
+    __doc__= """Rule-based segmenter relying on [PySBD](https://github.com/nipunsadvilkar/pySBD).
     #need-language
     #languages:""" + SUPPORTED_LANGUAGES
 
